@@ -1,5 +1,6 @@
 #!/bin/bash
 
 cd `dirname $0`
-PYTHONPATH=".." py.test
+PYTHONPATH=".." py.test $@
+
 
